/**
 * Arduino Sketch für SmartHome yourself - Arduino Lehrgang
 * 
 * Tag 17: Mehrere Buttons an einem Pin betreiben
 * 
 * In diesem Sketch lesen wir den Wert des Analogen Pins aus. 
 * Anhand des Rückgabewertes ermitteln wir, welcher Button gedrückt wurde und schalten dementsprechend die LED ein oder aus.
 * 
 * By Daniel Scheidler - Dezember 2019
 */

const unsigned int BUTTON_PIN   = A0;                           // Pin an dem die Buttons angeschlossen sind
const unsigned int ROTE_LED_PIN = 3;                            // Pin der LED

const unsigned int BUTTON_TOLLERANCE = 5;                       // Tolleranz die beim auslesen des Analog-Signals verwendet wird
                                                                // um den Button zuzuordnen. (Tolleranz wird in beide Richtungen verwendet)
 
const unsigned int BUTTON[2] = {1023, 970};                     // Array mit den Mittelwerten von analogRead() der einzelnen Buttons

void setup() {
  Serial.begin(9600);                                           // Serielle Kommunikation starten
  delay(1000);                                                  // 1 Sek. warten
  pinMode(BUTTON_PIN, INPUT);                                   // Button-Pin als Eingang definieren
  pinMode(ROTE_LED_PIN, OUTPUT);                                // LED-Pin als Ausgang definieren
}

void loop() {
  if(isButtonPressed(BUTTON[0])){                               // Prüfen ob Analogwert dem Wert des ersten Buttons entspricht.
    Serial.println("LED EIN");                                  // Falls ja, "LED EIN" auf seriellem Monitor ausgeben 
    digitalWrite(ROTE_LED_PIN, HIGH);                           // und LED einschalten.
  }
  
  if(isButtonPressed(BUTTON[1])){                               // Prüfen ob Analogwert dem Wert des zweiten Buttons entspricht.
    Serial.println("LED AUS");                                  // Falls ja, "LED AUS" auf seriellem Monitor ausgeben
    digitalWrite(ROTE_LED_PIN, LOW);                            // und LED ausschalten.
  }
  
  delay(250);                                                   // 250ms warten
}

/**
* Methode zum überprüfen ob ein Button gedrückt wurde 
* Die Methode vergleicht unter Berücksichtigung der definierten Tolleranz 
* den übergebenen Wert mit dem Wert des Button-Pins
*/
boolean isButtonPressed(unsigned int button){                   
  int analogValue = analogRead(BUTTON_PIN);                      // Analogwert des Button-Pins auslesen
  Serial.println(analogValue);                                   // Ergebnis auf Seriellem Monitor ausgeben

  return analogValue > button - BUTTON_TOLLERANCE                // zurückgeben ob analogValue im Tolleranzbereich des angegebenen Button-Wertes liegt
         && analogValue < button + BUTTON_TOLLERANCE;
}
 
